/**
 * Implement Gatsby's Browser APIs in this file.
 *
 * See: https://www.gatsbyjs.org/docs/browser-apis/
 */

// Test each one here
// import './../../scss/ibm-plex.scss'
import './../../css/ibm-plex.css'
